( cd usr/bin ; rm -rf eview )
( cd usr/bin ; ln -sf vim eview )
( cd usr/bin ; rm -rf evim )
( cd usr/bin ; ln -sf vim evim )
( cd usr/bin ; rm -rf ex )
( cd usr/bin ; ln -sf vim ex )
( cd usr/bin ; rm -rf rview )
( cd usr/bin ; ln -sf vim rview )
( cd usr/bin ; rm -rf rvim )
( cd usr/bin ; ln -sf vim rvim )
( cd usr/bin ; rm -rf view )
( cd usr/bin ; ln -sf vim view )
( cd usr/bin ; rm -rf vimdiff )
( cd usr/bin ; ln -sf vim vimdiff )
( cd usr/doc/vim-6.3 ; rm -rf doc )
( cd usr/doc/vim-6.3 ; ln -sf /usr/share/vim/vim63 doc )
( cd usr/man/man1 ; rm -rf ex.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/man1 ; rm -rf rview.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/man1 ; rm -rf rvim.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/man1 ; rm -rf view.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz view.1.gz )
#!/bin/sh
# If there's no vi link, take over:
if [ ! -r usr/bin/vi ]; then
  ( cd usr/bin ; ln -sf vim vi )
fi
