" Vim indent file
" Language:	    Zsh Shell Script
" Maintainer:	    Nikolai Weibull <source@pcppopper.org>
" URL:		    http://www.pcppopper.org/vim/indent/pcp/zsh/
" Latest Revision:  2004-05-22
" arch-tag:	    e566f55f-d8c0-4c60-b4b3-60c0dbd6dea1

" Same as sh indenting for now.
runtime! indent/sh.vim

" vim: set sts=2 sw=2:
