" Vim indent file
" Language:	    automake
" Maintainer:	    Nikolai Weibull <source@pcppopper.org>
" URL:		    http://www.pcppopper.org/vim/indent/pcp/automake/
" Latest Revision:  2004-04-25
" arch-tag:	    9a2af48c-48d4-4bae-82c3-c801bc9d1976

" same as makefile indenting for now.
source <sfile>:p:h/make.vim

" vim: set sts=2 sw=2:
