" Menu Translations:	Japanese (for UNIX)
" Translated By:	Muraoka Taro  <koron@tka.att.ne.jp>
" Last Change:		08:50:47 25-Mar-2001.

" ujis is the same as euc-jp.  Source the other one from here.
source <sfile>:p:h/menu_ja_jp.euc-jp.vim
