" Vim Keymap file for russian characters, phonetic layout 'yawerty'
" Useful mainly with utf-8 but may work with other encodings

" Maintainer:   Igor Goldenberg <igold@igold.pp.ru>
" Last Changed: 2002 Jan 14

" All characters are given literally, conversion to another encoding (e.g.,
" UTF-8) should work.
scriptencoding utf-8

let b:keymap_name = "ru"

loadkeymap
A	А	CYRILLIC CAPITAL LETTER A
B	Б	CYRILLIC CAPITAL LETTER BE
W	В	CYRILLIC CAPITAL LETTER VE
G	Г	CYRILLIC CAPITAL LETTER GHE
D	Д	CYRILLIC CAPITAL LETTER DE
E	Е	CYRILLIC CAPITAL LETTER IE
&	Ё	CYRILLIC CAPITAL LETTER IO
V	Ж	CYRILLIC CAPITAL LETTER ZHE
Z	З	CYRILLIC CAPITAL LETTER ZE
I	И	CYRILLIC CAPITAL LETTER I
J	Й	CYRILLIC CAPITAL LETTER SHORT I
K	К	CYRILLIC CAPITAL LETTER KA
L	Л	CYRILLIC CAPITAL LETTER EL
M	М	CYRILLIC CAPITAL LETTER EM
N	Н	CYRILLIC CAPITAL LETTER EN
O	О	CYRILLIC CAPITAL LETTER O
P	П	CYRILLIC CAPITAL LETTER PE
R	Р	CYRILLIC CAPITAL LETTER ER
S	С	CYRILLIC CAPITAL LETTER ES
T	Т	CYRILLIC CAPITAL LETTER TE
U	У	CYRILLIC CAPITAL LETTER U
F	Ф	CYRILLIC CAPITAL LETTER EF
H	Х	CYRILLIC CAPITAL LETTER HA
C	Ц	CYRILLIC CAPITAL LETTER TSE
+	Ч	CYRILLIC CAPITAL LETTER CHE
{	Ш	CYRILLIC CAPITAL LETTER SHA
}	Щ	CYRILLIC CAPITAL LETTER SHCHA
$	Ъ	CYRILLIC CAPITAL LETTER HARD SIGN
Y	Ы	CYRILLIC CAPITAL LETTER YERU
X	Ь	CYRILLIC CAPITAL LETTER SOFT SIGN
|	Э	CYRILLIC CAPITAL LETTER E
~	Ю	CYRILLIC CAPITAL LETTER YU
Q	Я	CYRILLIC CAPITAL LETTER YA
a	а	CYRILLIC SMALL LETTER A
b	б	CYRILLIC SMALL LETTER BE
w	в	CYRILLIC SMALL LETTER VE
g	г	CYRILLIC SMALL LETTER GHE
d	д	CYRILLIC SMALL LETTER DE
e	е	CYRILLIC SMALL LETTER IE
^	ё	CYRILLIC SMALL LETTER IO
v	ж	CYRILLIC SMALL LETTER ZHE
z	з	CYRILLIC SMALL LETTER ZE
i	и	CYRILLIC SMALL LETTER I
j	й	CYRILLIC SMALL LETTER SHORT I
k	к	CYRILLIC SMALL LETTER KA
l	л	CYRILLIC SMALL LETTER EL
m	м	CYRILLIC SMALL LETTER EM
n	н	CYRILLIC SMALL LETTER EN
o	о	CYRILLIC SMALL LETTER O
p	п	CYRILLIC SMALL LETTER PE
r	р	CYRILLIC SMALL LETTER ER
s	с	CYRILLIC SMALL LETTER ES
t	т	CYRILLIC SMALL LETTER TE
u	у	CYRILLIC SMALL LETTER U
f	ф	CYRILLIC SMALL LETTER EF
h	х	CYRILLIC SMALL LETTER HA
c	ц	CYRILLIC SMALL LETTER TSE
=	ч	CYRILLIC SMALL LETTER CHE
[	ш	CYRILLIC SMALL LETTER SHA
]	щ	CYRILLIC SMALL LETTER SHCHA
#	ъ	CYRILLIC SMALL LETTER HARD SIGN
y	ы	CYRILLIC SMALL LETTER YERU
x	ь	CYRILLIC SMALL LETTER SOFT SIGN
\\	э	CYRILLIC SMALL LETTER E
`	ю	CYRILLIC SMALL LETTER YU
q	я	CYRILLIC SMALL LETTER YA
