" Vim Keymap file for Hanyu Pinyin tone marks through numbers.
" Maintainer: Fredrik Roubert <roubert@df.lth.se>
" Last Changed: February 15, 2004

" All characters are given literally.
scriptencoding utf-8

" Use this short name in the status line.
let b:keymap_name = "py"

loadkeymap
a0	a
a1	ā
a2	á
a3	ǎ
a4	à
a5	a
e0	e
e1	ē
e2	é
e3	ě
e4	è
e5	e
i0	i
i1	ī
i2	í
i3	ǐ
i4	ì
i5	i
o0	o
o1	ō
o2	ó
o3	ǒ
o4	ò
o5	o
u0	u
u1	ū
u2	ú
u3	ǔ
u4	ù
u5	u
ü0	ü
ü1	ǖ
ü2	ǘ
ü3	ǚ
ü4	ǜ
ü5	ü
v0	ü
v1	ǖ
v2	ǘ
v3	ǚ
v4	ǜ
v5	ü

